@@ -44,13 +44,9 @@ void Palapeli::InteractorManager::resetActiveTriggers()
 void Palapeli::InteractorManager::handleEvent(QWheelEvent* event)
 {
 	//convert event
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
 	const QPoint angleDelta = event->angleDelta();
         const int delta = (qAbs(angleDelta.x()) > qAbs(angleDelta.y())) ? angleDelta.x() : angleDelta.y();
 	Palapeli::WheelEvent pEvent(m_view, event->position().toPoint(), delta);
-#else
-	Palapeli::WheelEvent pEvent(m_view, event->pos(), event->delta());
-#endif
 	//check which interactors are triggered by this event
 	Palapeli::Interactor* bestMatchInteractor = nullptr;
 	int bestMatchPriority = -1;
